# Cartoon Fight
Cartoon Fight is a 2D battle game to play against your friends
with your favorites cartoon characters.

## Install

`$ pip install cartoonfight` 

Cartoon Fight works with Python 3.6+.

To **update** it just run `$ pip install --upgrade cartoonfight`.

## Play

Just run `$ cartoonfight`.

## Game Controls

Press `A` or `D` to move Player One

Press `<-` or `->` to move Player Two
